==> ember-0.4.0.tar.bz2: ember-0.4.0/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeTexture_BaseTexture.h <==
/***************************************************************************
OgrePagingLandScapeTexture_BaseTexture.h  -  description
  -------------------
  begin                : Mon Apr 26 2004
  copyright            : (C) 2002-2005 by Jose A Milan & Tuan Kuranes
  email                : spoke@supercable.es & tuan.kuranes@free.fr
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation; either version 2 of the    *
*   License, or (at your option) any later version.                       *
*                                                                         *
***************************************************************************/

#ifndef PAGINGLandScapeTEXTURE_BASETEXTURE_H
#define PAGINGLandScapeTEXTURE_BASETEXTURE_H

#include "OgrePagingLandScapePrerequisites.h"

namespace Ogre
{
    class PagingLandScapeTexture_BaseTexture : public PagingLandScapeTexture
    {
        public:
	        PagingLandScapeTexture_BaseTexture(void);
            virtual String getName(){return String("BaseTexture");}
        	
            virtual void setPagesize(void){_setPagesize();};
            virtual void clearData(void){_clearData();};
            
            static void _setPagesize(void);
            static void _clearData(void);

	        virtual ~PagingLandScapeTexture_BaseTexture(void);

            virtual PagingLandScapeTexture* newTexture();
            virtual bool TextureRenderCapabilitesFullfilled(); 

        protected:
	        virtual void _loadMaterial(void);        	
	        virtual void _unloadMaterial(void);

        private:
            Image BaseImage;
			uchar *_BuildBaseTexture() const;
    };

}

#endif

==> ember-0.4.1.tar.bz2: ember-0.4.1/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeTexture_BaseTexture.h <==
/***************************************************************************
OgrePagingLandScapeTexture_BaseTexture.h  -  description
  -------------------
  begin                : Mon Apr 26 2004
  copyright            : (C) 2002-2005 by Jose A Milan & Tuan Kuranes
  email                : spoke@supercable.es & tuan.kuranes@free.fr
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation; either version 2 of the    *
*   License, or (at your option) any later version.                       *
*                                                                         *
***************************************************************************/

#ifndef PAGINGLandScapeTEXTURE_BASETEXTURE_H
#define PAGINGLandScapeTEXTURE_BASETEXTURE_H

#include "OgrePagingLandScapePrerequisites.h"

namespace Ogre
{
    class PagingLandScapeTexture_BaseTexture : public PagingLandScapeTexture
    {
        public:
	        PagingLandScapeTexture_BaseTexture(PagingLandScapeTextureManager *textureMgr);
            virtual String getName(){return String("BaseTexture");}
        	
            virtual void setPagesize(void){_setPagesize();};
            virtual void clearData(void){_clearData();};
            
            void _setPagesize(void);
            void _clearData(void);

	        virtual ~PagingLandScapeTexture_BaseTexture(void);

            virtual PagingLandScapeTexture* newTexture();
            virtual bool TextureRenderCapabilitesFullfilled(); 

        protected:
	        virtual void _loadMaterial(void);        	
	        virtual void _unloadMaterial(void);

        private:
            Image BaseImage;
			uchar *_BuildBaseTexture() const;
    };

}

#endif
